Class: SQLAnywhere::a_sqlany_bind_param_info

Inherits:
Object
  • Object
show all
Defined in:
ext/sqlanywhere.c

Instance Method Summary collapse

Instance Method Details

#get_info_direction(VALUEbind) ⇒ Object

Gets the name of the bound parameter info object.

<b>Parameters</b>:
- <tt>VALUE bind</tt> -- Bound parameter info retrieved from sqlany_describe_bind_param_info().

<b>Returns</b>:
- <tt>VALUE direction</tt>: The bound variable's direction.


1648
1649
1650
1651
1652
1653
1654
1655
# File 'ext/sqlanywhere.c', line 1648

static VALUE
static_Bind_get_info_direction(VALUE bind)
{
    a_sqlany_bind_param_info* s_bind;
    Data_Get_Struct(bind, a_sqlany_bind_param_info, s_bind);

    return (CHR2FIX(s_bind->direction));
}

#get_info_output(VALUEbind) ⇒ Object

Gets the value of a bound parameter after execution.

<b>Parameters</b>:
- <tt>VALUE bind</tt> -- Bound parameter retrieved from sqlany_describe_bind_param().

<b>Returns</b>:
- <tt>VALUE name</tt>: The bound variable value.


1670
1671
1672
1673
1674
1675
1676
# File 'ext/sqlanywhere.c', line 1670

static VALUE
static_Bind_get_info_output(VALUE bind)
{
    a_sqlany_bind_param_info* s_bind;
    Data_Get_Struct(bind, a_sqlany_bind_param_info, s_bind);
    return(C2RB(&s_bind->output_value));
}